import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import Plot from './Plot';
import Axis from './components/Axis';
import ParallelAxis from './components/Axis/ParallelAxis';
import Legend from './components/Legend';
import LineSeries from './components/LineSeries';
import ScatterSeries from './components/ScatterSeries';
export default function PlotObject({ plot: { dimensions, svg = {}, seriesViewportStyle, axes, series, legend, colorScheme, }, }) {
    const { className: svgClassName, id: svgId, style: svgStyle, ...svgProps } = svg;
    return (_jsxs(Plot, Object.assign({ colorScheme: colorScheme, seriesViewportStyle: seriesViewportStyle }, dimensions, { svgClassName: svgClassName, svgId: svgId, svgStyle: svgStyle }, svgProps, { children: [axes.map((axisProps) => {
                switch (axisProps.type) {
                    case 'main': {
                        const { type, ...props } = axisProps;
                        return _jsx(Axis, Object.assign({}, props), axisProps.position);
                    }
                    case 'secondary': {
                        const { type, ...props } = axisProps;
                        return _jsx(ParallelAxis, Object.assign({}, props), `secondary-${props.id}`);
                    }
                    default: {
                        return null;
                    }
                }
            }),
            legend !== undefined ? _jsx(Legend, Object.assign({}, legend), void 0) : null,
            series.map((seriesProps, i) => {
                switch (seriesProps.type) {
                    case 'line': {
                        const { type, ...props } = seriesProps;
                        // eslint-disable-next-line react/no-array-index-key
                        return _jsx(LineSeries, Object.assign({}, props), `lineseries-${i}`);
                    }
                    case 'scatter': {
                        const { type, ...props } = seriesProps;
                        // eslint-disable-next-line react/no-array-index-key
                        return _jsx(ScatterSeries, Object.assign({}, props), `scatterseries-${i}`);
                    }
                    default: {
                        return null;
                    }
                }
            })] }), void 0));
}
//# sourceMappingURL=PlotObject.js.map