import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { useMemo } from 'react';
import { usePlotContext } from '../../hooks';
import VerticalText from '../VerticalText';
import { Ticks } from './Ticks';
export default function LeftAxis({ id, displayGridLines, hidden = false, label, labelSpace, labelStyle, fontSize, tickStyle, hiddenTicks = false, tickEmbedded, tickLength, hiddenSecondaryTicks, }) {
    const { axisContext, plotHeight, plotWidth } = usePlotContext();
    // Calculates the main axis values
    const { scale, scientific } = axisContext[id] || {};
    const ticks = useMemo(() => (scale === null || scale === void 0 ? void 0 : scale.ticks()) || [], [scale]);
    const range = (scale === null || scale === void 0 ? void 0 : scale.range()) || [0, 0];
    // Create gridlines
    const gridlines = useMemo(() => {
        if (!displayGridLines || !scale)
            return null;
        return (_jsx("g", Object.assign({ className: "gridLines" }, { children: ticks.map((val) => (_jsx("line", { x1: "0", x2: plotWidth, y1: scale(val), y2: scale(val), stroke: "black", strokeDasharray: "2,2", strokeOpacity: 0.5 }, val))) }), void 0));
    }, [displayGridLines, ticks, scale, plotWidth]);
    const tickDirection = tickEmbedded ? 1 : -1;
    const tickLen = tickDirection * tickLength;
    const tickTextPosition = tickEmbedded ? -8 : -8 + tickLen;
    return (_jsxs("g", Object.assign({ className: "axis" }, { children: [gridlines, !hidden && (_jsxs("g", Object.assign({ className: "ticks" }, { children: [_jsx("line", { y1: range[0], y2: range[1], stroke: "black" }, void 0),
                    _jsx(Ticks, { scientific: scientific, scale: scale, hidden: hiddenTicks, ticks: ticks, style: tickStyle, hiddenSecondaryTicks: hiddenSecondaryTicks, getPositions: (y) => ({
                            line: { x2: tickLen, y1: y, y2: y },
                            text: { x1: tickTextPosition, y1: y },
                        }) }, void 0)] }), void 0)),
            label && !hidden && (_jsx(VerticalText, { label: label, transform: `translate(${0 - fontSize - labelSpace - (scientific ? 14 : 0)}, ${plotHeight / 2})`, dy: fontSize, fontSize: fontSize, style: labelStyle }, void 0))] }), void 0));
}
//# sourceMappingURL=LeftAxis.js.map